@@ -1,18 +1,11 @@
-from copy import deepcopy
-
 from workplace_extractor.Nodes.NodeCollection import PostCollection, NodeCollection, InteractionCollection
 from workplace_extractor.Extractors import PostExtractor
 
 
 import pandas as pd
-import numpy as np
 import networkx as nx
-import matplotlib.pyplot as plt
-# import matplotlib
-# from random import randint
 import pickle
 import operator
-# import math
 
 
 class InteractionExtractor:
@@ -20,20 +13,21 @@ class InteractionExtractor:
         self.extractor = extractor
 
         self.feeds = PostCollection()
-        # self.net = since
+        self.net = None
+        self.pagerank = None
 
         self.nodes = InteractionCollection()
 
     async def extract(self):
         post_extractor = PostExtractor(self.extractor)
-        await post_extractor.extract()
-        self.feeds = post_extractor.nodes
+        #await post_extractor.extract()
+        #self.feeds = post_extractor.nodes
 
-        with open(f'{self.extractor.config.get("MISC", "output_dir")}/workplace_interactions-newnew.pickle', 'wb') as handle:
-            pickle.dump(self.feeds, handle)
+        # with open(f'{self.extractor.config.get("MISC", "output_dir")}/workplace_interactions.pickle', 'wb') as handle:
+        #    pickle.dump(self.feeds, handle)
 
-        # with open('/Users/denisduarte/Petrobras/PythonProjects/workplace_extractor/output2/workplace_interactions-newnew.pickle', 'rb') as handle:
-        #    self.feeds = pickle.load(handle)
+        #with open(f'{self.extractor.config.get("MISC", "output_dir")}/workplace_interactions.pickle', 'rb') as handle:
+        #     self.feeds = pickle.load(handle)
 
         user_summary = self.build_user_summary()
         self.net = self.build_net()
@@ -49,7 +43,20 @@ class InteractionExtractor:
 
     def build_net(self, include_inactive=False):
 
-        diretorias = pd.read_excel(f'{self.extractor.config.get("MISC", "output_dir")}/dDiretorias.xlsx')
+        ### Create list of node attributes
+
+        # Attributes coming from the extraction
+        node_attribute_list = []
+        if self.extractor.node_attributes:
+            node_attribute_list = self.extractor.node_attributes.split(',')
+
+        # Additional attributes coming from a external file
+        additional_attributes = pd.read_csv(self.extractor.additional_node_attributes, sep=';')
+
+        node_additional_attribute_list = additional_attributes.columns.values.tolist()
+        node_additional_attribute_list.remove(self.extractor.joining_column)
+
+        ### Build the net
 
         net = nx.Graph()
         for node in self.feeds.nodes:
@@ -57,46 +64,21 @@ class InteractionExtractor:
                 for post in node.feed.nodes:
                     if post.author.node_id != 'None' and (post.author.active or include_inactive):
 
-                        author_diretoria = ''
-                        try:
-                            division = diretorias['Área'] == getattr(post.author, 'division')
-                            author_diretoria = diretorias.loc[division, 'Diretoria'].iloc[0]
-                        except:
-                            pass
-
                         if post.comments['data'] is not None and post.comments['data'].nodes:
                             net.add_node(post.author.node_id,
-                                         color=getattr(post.author, self.extractor.config.get('PLOT', 'color_field')),
-                                         label=getattr(post.author, self.extractor.config.get('PLOT', 'label_field')),
-                                         diretoria=author_diretoria,
-                                         division=getattr(post.author, 'division'),
-                                         department=getattr(post.author, 'department'),
-                                         name=getattr(post.author, 'name'),
-                                         emp_num=getattr(post.author, 'emp_num'),
-                                         email=getattr(post.author, 'email'))
+                                         **self.list_node_attributes(post.author, self.extractor,
+                                                                     node_attribute_list,
+                                                                     node_additional_attribute_list,
+                                                                     additional_attributes))
 
                             for comment in post.comments['data'].nodes:
                                 # remove external users
                                 if comment.person.node_id != 'None' and (comment.person.active or include_inactive):
-
-                                    comment_diretoria = ''
-                                    try:
-                                        division = diretorias['Área'] == getattr(comment.person, 'division')
-                                        comment_diretoria = diretorias.loc[division, 'Diretoria'].iloc[0]
-                                    except:
-                                        pass
-
                                     net.add_node(comment.person.node_id,
-                                                 color=getattr(comment.person,
-                                                               self.extractor.config.get('PLOT', 'color_field')),
-                                                 label=getattr(comment.person,
-                                                               self.extractor.config.get('PLOT', 'label_field')),
-                                                 diretoria=comment_diretoria,
-                                                 division=getattr(comment.person, 'division'),
-                                                 department=getattr(comment.person, 'department'),
-                                                 name=getattr(comment.person, 'name'),
-                                                 emp_num=getattr(comment.person, 'emp_num'),
-                                                 email=getattr(comment.person, 'email'))
+                                                 **self.list_node_attributes(comment.person, self.extractor,
+                                                                             node_attribute_list,
+                                                                             node_additional_attribute_list,
+                                                                             additional_attributes))
 
                                     if net.has_edge(post.author.node_id, comment.person.node_id):
                                         # we added this one before, just increase the weight by one
@@ -106,39 +88,20 @@ class InteractionExtractor:
                                         net.add_edge(post.author.node_id, comment.person.node_id, weight=1)
 
                         if post.reactions['data'] is not None and post.reactions['data'] and post.author.node_id != 'None':
-
                             net.add_node(post.author.node_id,
-                                         color=getattr(post.author, self.extractor.config.get('PLOT', 'color_field')),
-                                         label=getattr(post.author, self.extractor.config.get('PLOT', 'label_field')),
-                                         diretoria=author_diretoria,
-                                         division=getattr(post.author, 'division'),
-                                         department=getattr(post.author, 'department'),
-                                         name=getattr(post.author, 'name'),
-                                         emp_num=getattr(post.author, 'emp_num'),
-                                         email=getattr(post.author, 'email'))
+                                         **self.list_node_attributes(post.author, self.extractor,
+                                                                     node_attribute_list,
+                                                                     node_additional_attribute_list,
+                                                                     additional_attributes))
 
                             for reaction in post.reactions['data']:
                                 # remove external users
                                 if reaction.person.node_id != 'None' and (reaction.person.active or include_inactive):
-
-                                    reaction_diretoria = ''
-                                    try:
-                                        division = diretorias['Área'] == getattr(reaction.person, 'division')
-                                        reaction_diretoria = diretorias.loc[division, 'Diretoria'].iloc[0]
-                                    except:
-                                        pass
-
                                     net.add_node(reaction.person.node_id,
-                                                 color=getattr(reaction.person,
-                                                               self.extractor.config.get('PLOT', 'color_field')),
-                                                 label=getattr(reaction.person,
-                                                               self.extractor.config.get('PLOT', 'label_field')),
-                                                 diretoria=reaction_diretoria,
-                                                 division=getattr(reaction.person, 'division'),
-                                                 department=getattr(reaction.person, 'department'),
-                                                 name=getattr(reaction.person, 'name'),
-                                                 emp_num=getattr(reaction.person, 'emp_num'),
-                                                 email=getattr(reaction.person, 'email'))
+                                                 **self.list_node_attributes(reaction.person, self.extractor,
+                                                                             node_attribute_list,
+                                                                             node_additional_attribute_list,
+                                                                             additional_attributes))
 
                                     if net.has_edge(post.author.node_id, reaction.person.node_id):
                                         # we added this one before, just increase the weight by one
@@ -209,86 +172,6 @@ class InteractionExtractor:
         ranking.replace(to_replace=[r"\\t|\\n|\\r", "\t|\n|\r"], value=[" ", " "], regex=True) \
                .to_csv(f'{self.extractor.config.get("MISC", "output_dir")}/rank_{ranking_type}.csv', index=False, sep=";")
 
-    def create_network_plot(self):
-
-        net = deepcopy(self.net)
-
-        max_rank = max(self.pagerank.items(), key=operator.itemgetter(1))[1]
-
-        remove = [node for node, rank in self.pagerank.items() if rank < max_rank * 0.05]
-
-        centrality = sorted(self.pagerank.items(), key=operator.itemgetter(1), reverse=True)
-
-        max_nodes = 200
-        max_index = min([max_nodes, net.number_of_nodes()-1])
-
-        remove = [node for node, rank in self.pagerank.items() if rank < centrality[max_index][1]]
-        net.remove_nodes_from(remove)
-
-        node_ref = self.extractor.person_id
-
-        # neighbours = [node for node in net.neighbors(node_ref)]
-        # neighbours.append(node_ref)
-        # remove = [node for node, rank in self.pagerank.items() if node not in neighbours]
-        # net.remove_nodes_from(remove)
-
-        # remove = [node for node, rank in self.pagerank.items() if rank < max_rank * 0.05]
-        # net.remove_nodes_from(remove)
-
-        colors = pd.DataFrame({node: net.nodes()[node]['diretoria'] for node in net.nodes()}, index=[0]).transpose()
-        colors = colors.rename(columns={0: 'color'})
-        colors['color'] = pd.Categorical(colors['color'])
-
-        maxval = len(set(colors['color'].cat.codes))
-
-        cmap = plt.cm.Spectral
-
-        options = {
-            'width': 0.1,
-            'node_size': [min(self.pagerank[node] * 5000, 500) for node in net.nodes()],
-            'node_color': [cmap(1.5*v/maxval) for v in colors['color'].cat.codes],
-            'cmap': cmap,
-            'with_labels': False,
-            'edge_color': (0, 0, 0, 0.9),
-            'edgecolors': (0, 0, 0, 0.9),
-            'linewidths': 0.1
-        }
-
-        plt.figure()
-        pos_nodes = nx.circular_layout(net)
-        pos_nodes[node_ref] = np.array([0, 0])
-
-        for node in pos_nodes:
-            if node != node_ref:
-                # print(net[node_ref][node]['weight'])
-                wt = net[node_ref][node]['weight']
-                wt = float(wt)
-                pos_nodes[node] /= np.log10(wt**wt)+1
-
-        nx.draw(net, pos_nodes, **options)
-
-        pos_attrs = {}
-        for node, coords in pos_nodes.items():
-            pos_attrs[node] = (coords[0], coords[1] + 0.04)
-
-        options = {
-            'labels': {node: net.nodes()[node]['label'] if self.pagerank[node] >= max_rank * 0.5 else '' for node in net.nodes()},
-            'font_size': 7,
-            'font_color': 'red'
-        }
-
-        nx.draw_networkx_labels(net, pos_attrs, **options)
-
-        for v in set(colors['color'].cat.codes):
-            plt.scatter([], [], c=[cmap(1.5*v / maxval)], label=colors['color'].cat.categories[v])
-
-        plt.legend()
-        plt.show()
-
-        plt.savefig(self.extractor.config.get('MISC', 'output_dir') + 'interactions_plot.png')
-
-        plt.show()
-
     def build_user_summary(self):
         df = pd.DataFrame(columns=['posts', 'post_reactions', 'post_views',
                                    'comments', 'comment_reactions',
@@ -337,3 +220,21 @@ class InteractionExtractor:
         data.loc[data['user_id'] == user.node_id, action] += 1
 
         return data
+
+    @staticmethod
+    def list_node_attributes(node, extractor,
+                             node_attribute_list, node_additional_attribute_list, additional_attributes):
+
+        attributes = {}
+
+        for attribute in node_attribute_list:
+            attributes[attribute] = getattr(node, attribute)
+
+        current_row_loc = additional_attributes[extractor.joining_column] == getattr(
+            node, extractor.joining_column)
+
+        for attribute in node_additional_attribute_list:
+            if not additional_attributes.loc[current_row_loc, attribute].empty:
+                attributes[attribute] = additional_attributes.loc[current_row_loc, attribute].iloc[0]
+
+        return attributes
